diff mbox series

[v1,5/8] ACPICA: actbl1: Add EINJv2 get error type action

Message ID 3344273.aeNJFYEL58@rjwysocki.net (mailing list archive)
State Queued
Delegated to: Rafael Wysocki
Headers show
Series ACPICA: ACPICA 20241212 | expand

Commit Message

Rafael J. Wysocki March 26, 2025, 8:08 p.m. UTC
From: Zaid Alali <zaidal@os.amperecomputing.com>

ACPICA commit 6975cd07e20ba955556e1eafe8a326834c354ae6

Add EINJV2_GET_ERROR_TYPE as defined in the new specs(1)(2).

Link: https://bugzilla.tianocore.org/show_bug.cgi?id=4615 (1)
Link: https://bugzilla.tianocore.org/attachment.cgi?id=1446 (2)
Link: https://github.com/acpica/acpica/commit/6975cd07
Signed-off-by: Zaid Alali <zaidal@os.amperecomputing.com>
Signed-off-by: Rafael J. Wysocki <rafael.j.wysocki@intel.com>
---
 include/acpi/actbl1.h | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)
diff mbox series

Patch

diff --git a/include/acpi/actbl1.h b/include/acpi/actbl1.h
index 1dc29933e2a3..329454c303b9 100644
--- a/include/acpi/actbl1.h
+++ b/include/acpi/actbl1.h
@@ -1034,7 +1034,8 @@  enum acpi_einj_actions {
 	ACPI_EINJ_GET_COMMAND_STATUS = 0x7,
 	ACPI_EINJ_SET_ERROR_TYPE_WITH_ADDRESS = 0x8,
 	ACPI_EINJ_GET_EXECUTE_TIMINGS = 0x9,
-	ACPI_EINJ_ACTION_RESERVED = 0xA,	/* 10 and greater are reserved */
+	ACPI_EINJV2_GET_ERROR_TYPE = 0x11,
+	ACPI_EINJ_ACTION_RESERVED = 0x12,	/* 0x12 and greater are reserved */
 	ACPI_EINJ_TRIGGER_ERROR = 0xFF	/* Except for this value */
 };